@@ -10,9 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from neutron_lib.api.definitions import address_group
 from neutron_lib.api.definitions import address_scope
 from neutron_lib.api.definitions import agent
 from neutron_lib.api.definitions import agent_resources_synced
+from neutron_lib.api.definitions import agent_sort_key
 from neutron_lib.api.definitions import allowedaddresspairs
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
@@ -70,6 +72,7 @@ from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
 from neutron_lib.api.definitions import port_mac_address_regenerate
+from neutron_lib.api.definitions import port_numa_affinity_policy
 from neutron_lib.api.definitions import port_resource_request
 from neutron_lib.api.definitions import port_security
 from neutron_lib.api.definitions import portbindings
@@ -93,6 +96,7 @@ from neutron_lib.api.definitions import router_admin_state_down_before_update
 from neutron_lib.api.definitions import router_availability_zone
 from neutron_lib.api.definitions import router_interface_fip
 from neutron_lib.api.definitions import routerservicetype
+from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
@@ -121,9 +125,11 @@ from neutron_lib.api.definitions import vpn_flavors
 
 
 _ALL_API_DEFINITIONS = {
+    address_group,
     address_scope,
     agent,
     agent_resources_synced,
+    agent_sort_key,
     allowedaddresspairs,
     auto_allocated_topology,
     availability_zone,
@@ -181,6 +187,7 @@ _ALL_API_DEFINITIONS = {
     pagination,
     port,
     port_mac_address_regenerate,
+    port_numa_affinity_policy,
     port_resource_request,
     port_security,
     portbindings,
@@ -204,6 +211,7 @@ _ALL_API_DEFINITIONS = {
     router_availability_zone,
     router_interface_fip,
     routerservicetype,
+    security_groups_normalized_cidr,
     security_groups_port_filtering,
     segment,
     segments_peer_subnet_host_routes,
